EZFF - Easy forcefield fitting
==============================

.. autoclass:: ezff.FFParam
   :members:

   .. automethod:: __init__
   .. automethod:: read_variable_bounds
   .. automethod:: read_forcefield_template
   .. automethod:: set_algorithm
   .. automethod:: ask
   .. automethod:: parameterize
   .. automethod:: get_best_recommendation
   .. automethod:: generate_pool
   .. automethod:: save_evaluated
   .. automethod:: load_evaluated
   .. automethod:: normalize_errors


.. automodule:: ezff
   :members: get_pool_rank
